@@ -1,7 +1,14 @@
+from add_on import AddOn
 from address import Address
+from address_gateway import AddressGateway
+from braintree_gateway import BraintreeGateway
 from configuration import Configuration
 from credit_card import CreditCard
+from credit_card_gateway import CreditCardGateway
+from credit_card_verification import CreditCardVerification
 from customer import Customer
+from customer_gateway import CustomerGateway
+from discount import Discount
 from error_codes import ErrorCodes
 from error_result import ErrorResult
 from errors import Errors
@@ -9,12 +16,15 @@ from environment import Environment
 from resource_collection import ResourceCollection
 from search import Search
 from subscription import Subscription
+from subscription_gateway import SubscriptionGateway
 from status_event import StatusEvent
 from transaction import Transaction
+from transaction_gateway import TransactionGateway
 from transaction_search import TransactionSearch
 from subscription_search import SubscriptionSearch
 from successful_result import SuccessfulResult
 from transaction_amounts import TransactionAmounts
 from transparent_redirect import TransparentRedirect
+from transparent_redirect_gateway import TransparentRedirectGateway
 from validation_error_collection import ValidationErrorCollection
 from version import Version
