@@ -17,7 +17,8 @@ class ErrorCodes(object):
         CountryCodeAlpha3IsNotAccepted = "91816"
         CountryCodeNumericIsNotAccepted = "91817"
         CountryNameIsNotAccepted = "91803"
-        ExtedAddressIsTooLong = "81804"
+        ExtedAddressIsTooLong = "81804" # Deprecated
+        ExtendedAddressIsTooLong = "81804"
         FirstNameIsTooLong = "81805"
         InconsistentCountry = "91815"
         LastNameIsTooLong = "81806"
@@ -69,7 +70,8 @@ class ErrorCodes(object):
         FaxIsTooLong = "81607"
         FirstNameIsTooLong = "81608"
         IdIsInUse = "91609"
-        IdIsInvaild = "91610"
+        IdIsInvaild = "91610" # Deprecated
+        IdIsInvalid = "91610"
         IdIsNotAllowed = "91611"
         IdIsRequired = "91613"
         IdIsTooLong = "91612"
@@ -79,9 +81,24 @@ class ErrorCodes(object):
         WebsiteIsTooLong = "81615"
 
     class Subscription(object):
+        BillingDayOfMonthCannotBeUpdated = "91918"
+        BillingDayOfMonthIsInvalid = "91914"
+        BillingDayOfMonthMustBeNumeric = "91913"
+        CannotAddDuplicateAddonOrDiscount = "91911"
         CannotEditCanceledSubscription = "81901"
+        CannotEditExpiredSubscription = "81910"
+        CannotEditPriceChangingFieldsOnPastDueSubscription = "91920"
+        FirstBillingDateCannotBeInThePast = "91916"
+        FirstBillingDateCannotBeUpdated = "91919"
+        FirstBillingDateIsInvalid = "91915"
         IdIsInUse = "81902"
+        InconsistentNumberOfBillingCycles = "91908"
+        InconsistentStartDate = "91917"
         MerchantAccountIdIsInvalid = "91901"
+        NumberOfBillingCyclesCannotBeBlank = "91912"
+        NumberOfBillingCyclesIsTooSmall = "91909"
+        NumberOfBillingCyclesMustBeGreaterThanZero = "91907"
+        NumberOfBillingCyclesMustBeNumeric = "91906"
         PaymentMethodTokenCardTypeIsNotAccepted = "91902"
         PaymentMethodTokenIsInvalid = "91903"
         PaymentMethodTokenNotAssociatedWithCustomer = "91905"
@@ -94,11 +111,32 @@ class ErrorCodes(object):
         TrialDurationIsRequired = "81908"
         TrialDurationUnitIsInvalid = "81909"
 
+        class Modification(object):
+            AmountCannotBeBlank = "92003"
+            AmountIsInvalid = "92002"
+            CannotEditModificationsOnPastDueSubscription = "92022"
+            CannotUpdateAndRemove = "92015"
+            ExistingIdIsIncorrectKind = "92020"
+            ExistingIdIsInvalid = "92011"
+            ExistingIdIsRequired = "92012"
+            IdToRemoveIsIncorrectKind = "92021"
+            IdToRemoveIsNotPresent = "92016"
+            InconsistentNumberOfBillingCycles = "92018"
+            InheritedFromIdIsInvalid = "92013"
+            InheritedFromIdIsRequired = "92014"
+            NumberOfBillingCyclesCannotBeBlank = "92017"
+            NumberOfBillingCyclesIsInvalid = "92005"
+            NumberOfBillingCyclesMustBeGreaterThanZero = "92019"
+            QuantityCannotBeBlank = "92004"
+            QuantityIsInvalid = "92001"
+            QuantityMustBeGreaterThanZero = "92010"
+
     class Transaction(object):
         AmountCannotBeNegative = "81501"
         AmountIsRequired = "81502"
         AmountIsInvalid = "81503"
         AmountIsTooLarge = "81528"
+        AmountMustBeGreaterThanZero = "81531"
         BillingAddressConflict = "91530"
         CannotBeVoided = "91504"
         CannotRefundCredit = "91505"
@@ -111,8 +149,10 @@ class ErrorCodes(object):
         CustomerIdIsInvalid = "91510"
         CustomerDoesNotHaveCreditCard = "91511"
         HasAlreadyBeenRefunded = "91512"
-        MerchantAccountNameIsInvalid = "91513"
-        MerchantAccountIsSusped = "91514"
+        MerchantAccountNameIsInvalid = "91513" # Deprecated
+        MerchantAccountIdIsInvalid = "91513"
+        MerchantAccountIsSusped = "91514" # Deprecated
+        MerchantAccountIsSuspended = "91514"
         OrderIdIsTooLong = "91501"
         PaymentMethodConflict = "91515"
         PaymentMethodDoesNotBelongToCustomer = "91516"
@@ -125,6 +165,7 @@ class ErrorCodes(object):
         SettlementAmountIsTooLarge = "91522"
         SubscriptionDoesNotBelongToCustomer = "91529"
         SubscriptionIdIsInvalid = "91528"
+        SubscriptionStatusMustBePastDue = "91531"
         TypeIsInvalid = "91523"
         TypeIsRequired = "91524"
 
