@@ -2,12 +2,15 @@ from decimal import Decimal
 from braintree.util.http import Http
 import braintree
 import warnings
+from braintree.add_on import AddOn
+from braintree.discount import Discount
 from braintree.exceptions.not_found_error import NotFoundError
 from braintree.resource_collection import ResourceCollection
 from braintree.successful_result import SuccessfulResult
 from braintree.error_result import ErrorResult
 from braintree.transaction import Transaction
 from braintree.resource import Resource
+from braintree.configuration import Configuration
 
 class Subscription(Resource):
     """
@@ -46,12 +49,16 @@ class Subscription(Resource):
 
         * braintree.Subscription.Status.Active
         * braintree.Subscription.Status.Canceled
+        * braintree.Subscription.Status.Expired
         * braintree.Subscription.Status.PastDue
+        * braintree.Subscription.Status.Pending
         """
 
         Active = "Active"
         Canceled = "Canceled"
+        Expired = "Expired"
         PastDue = "Past Due"
+        Pending = "Pending"
 
     @staticmethod
     def create(params={}):
@@ -63,25 +70,31 @@ class Subscription(Resource):
                 "plan_id": "some_plan_id",
             })
         """
-        Resource.verify_keys(params, Subscription.create_signature())
-        response = Http().post("/subscriptions", {"subscription": params})
-        if "subscription" in response:
-            return SuccessfulResult({"subscription": Subscription(response["subscription"])})
-        elif "api_error_response" in response:
-            return ErrorResult(response["api_error_response"])
+
+        return Configuration.gateway().subscription.create(params)
 
     @staticmethod
     def create_signature():
         return [
+            "billing_day_of_month",
+            "first_billing_date",
             "id",
             "merchant_account_id",
+            "never_expires",
+            "number_of_billing_cycles",
             "payment_method_token",
             "plan_id",
             "price",
             "trial_duration",
             "trial_duration_unit",
-            "trial_period"
-        ]
+            "trial_period",
+            {
+                "options": [
+                    "do_not_inherit_add_ons_or_discounts",
+                    "start_immediately"
+                ]
+            }
+        ] + Subscription._add_ons_discounts_signature()
 
     @staticmethod
     def find(subscription_id):
@@ -93,11 +106,7 @@ class Subscription(Resource):
             subscription = braintree.Subscription.find("my_subscription_id")
         """
 
-        try:
-            response = Http().get("/subscriptions/" + subscription_id)
-            return Subscription(response["subscription"])
-        except NotFoundError:
-            raise NotFoundError("subscription with id " + subscription_id + " not found")
+        return Configuration.gateway().subscription.find(subscription_id)
 
     @staticmethod
     def retryCharge(subscription_id, amount=None):
@@ -106,15 +115,7 @@ class Subscription(Resource):
 
     @staticmethod
     def retry_charge(subscription_id, amount=None):
-        response = Http().post("/transactions", {"transaction": {
-            "amount": amount,
-            "subscription_id": subscription_id,
-            "type": Transaction.Type.Sale
-            }})
-        if "transaction" in response:
-            return SuccessfulResult({"transaction": Transaction(response["transaction"])})
-        elif "api_error_response" in response:
-            return ErrorResult(response["api_error_response"])
+        return Configuration.gateway().subscription.retry_charge(subscription_id, amount)
 
     @staticmethod
     def update(subscription_id, params={}):
@@ -127,12 +128,7 @@ class Subscription(Resource):
             })
         """
 
-        Resource.verify_keys(params, Subscription.update_signature())
-        response = Http().put("/subscriptions/" + subscription_id, {"subscription": params})
-        if "subscription" in response:
-            return SuccessfulResult({"subscription": Subscription(response["subscription"])})
-        elif "api_error_response" in response:
-            return ErrorResult(response["api_error_response"])
+        return Configuration.gateway().subscription.update(subscription_id, params)
 
     @staticmethod
     def cancel(subscription_id):
@@ -141,14 +137,11 @@ class Subscription(Resource):
 
             result = braintree.Subscription.cancel("my_subscription_id")
         """
-        response = Http().put("/subscriptions/" + subscription_id + "/cancel")
-        if "subscription" in response:
-            return SuccessfulResult({"subscription": Subscription(response["subscription"])})
-        elif "api_error_response" in response:
-            return ErrorResult(response["api_error_response"])
+
+        return Configuration.gateway().subscription.cancel(subscription_id)
 
     @staticmethod
-    def search(query):
+    def search(*query):
         """
         Allows searching on subscriptions. There are two types of fields that are searchable: text and
         multiple value fields. Searchable text fields are:
@@ -167,38 +160,48 @@ class Subscription(Resource):
                 braintree.SubscriptionSearch.status.in_list([braintree.Subscription.Status.PastDue])
             ])
         """
-        response = Http().post("/subscriptions/advanced_search_ids", {"search": Subscription.__criteria(query)})
-        return ResourceCollection(query, response, Subscription.__fetch)
 
-    @staticmethod
-    def __fetch(query, ids):
-        criteria = Subscription.__criteria(query)
-        criteria["ids"] = braintree.subscription_search.SubscriptionSearch.ids.in_list(ids).to_param()
-        response = Http().post("/subscriptions/advanced_search", {"search": criteria})
-        return [Subscription(item) for item in ResourceCollection._extract_as_array(response["subscriptions"], "subscription")]
-
-    @staticmethod
-    def __criteria(query):
-        criteria = {}
-        for term in query:
-            if criteria.get(term.name):
-                criteria[term.name] = dict(criteria[term.name].items() + term.to_param().items())
-            else:
-                criteria[term.name] = term.to_param()
-        return criteria
+        return Configuration.gateway().subscription.search(*query)
 
     @staticmethod
     def update_signature():
         return [
             "id",
             "merchant_account_id",
+            "never_expires",
+            "number_of_billing_cycles",
             "payment_method_token",
             "plan_id",
-            "price"
+            "price",
+            {
+                "options": [ "prorate_charges", "replace_all_add_ons_and_discounts" ]
+            }
+        ] + Subscription._add_ons_discounts_signature()
+
+    @staticmethod
+    def _add_ons_discounts_signature():
+        return [
+            {
+                "add_ons": [{
+                    "add": ["amount", "inherited_from_id", "never_expires", "number_of_billing_cycles", "quantity"],
+                    "remove": ["__any_key__"],
+                    "update": ["amount", "existing_id", "never_expires", "number_of_billing_cycles", "quantity"]
+                }],
+                "discounts": [{
+                    "add": ["amount", "inherited_from_id", "never_expires", "number_of_billing_cycles", "quantity"],
+                    "remove": ["__any_key__"],
+                    "update": ["amount", "existing_id", "never_expires", "number_of_billing_cycles", "quantity"]
+                }]
+            }
         ]
 
-    def __init__(self, attributes):
-        Resource.__init__(self, attributes)
+    def __init__(self, gateway, attributes):
+        Resource.__init__(self, gateway, attributes)
         self.price = Decimal(self.price)
+        if "add_ons" in attributes:
+            self.add_ons = [AddOn(gateway, add_on) for add_on in self.add_ons]
+        if "discounts" in attributes:
+            self.discounts = [Discount(gateway, discount) for discount in self.discounts]
         if "transactions" in attributes:
-            self.transactions = [Transaction(transaction) for transaction in self.transactions]
+            self.transactions = [Transaction(gateway, transaction) for transaction in self.transactions]
+
